IntoMediaStore

Trait IntoMediaStore 

pub trait IntoMediaStore { }
A type that can be type-erased into Arc<dyn MediaStore>.

This trait is not meant to be implemented directly outside matrix-sdk-base, but it is automatically implemented for everything that implements MediaStore.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoMediaStore for Arc<dyn MediaStore<Error = MediaStoreError>>

Source

impl<T> IntoMediaStore for Arc<T>
where T: MediaStore + 'static,

Implementors

Source

impl<T> IntoMediaStore for T
where T: MediaStore + 'static,